import { FC, PropsWithChildren } from 'react';
import { ComparisonOptionModel, FilterData, FilterDataValue, FilterItemEvent, FilterOption, FilterProps, FlyoutModeFunction } from '../type';
import { OptionModel, OptionSingleValue, OptionMultipleValue, FlyoutMode } from '../../flyout/type';
interface FilterComparisonChangeEvent {
    key: string;
    index: number;
    filterItem?: FilterOption | null;
    mainItem?: FilterOption | null;
    comparison?: OptionSingleValue;
    comparisonItem?: ComparisonOptionModel;
    comparisons?: ComparisonOptionModel[];
    parent?: OptionModel;
}
interface FilterChangeEvent extends FilterComparisonChangeEvent {
    item?: OptionModel;
    values: OptionMultipleValue;
}
interface FilterMultipleChangeEvent extends FilterComparisonChangeEvent {
    addOption?: OptionModel;
    removeOption?: OptionModel;
}
interface FilterUpcomingItem {
    key: string;
    index: number;
    value: FilterDataValue;
}
interface FilterContextModel extends Omit<FilterProps, 'onFilter'> {
    selectedOptionKey: string | null;
    setSelectedOptionKey: (key: string | null) => void;
    selectedOptionIndex: number | null;
    upcomingItem: FilterUpcomingItem | null;
    onSelectItem: (key: string | null) => void;
    onChange: (args: FilterChangeEvent) => FilterData;
    onChangeMultiple: (args: FilterMultipleChangeEvent) => FilterData;
    onRemoveFilter: (key: string, index: number) => void;
    onChangeComparison: (args: FilterComparisonChangeEvent) => FilterData;
    onClearing: () => void;
    getValue: (key: string, index: number) => FilterDataValue | null;
    getOption: (value: OptionSingleValue, options?: OptionModel[]) => FilterOption | null;
    getMode: (mode?: FlyoutMode | FlyoutModeFunction, val?: FilterDataValue | null) => FlyoutMode;
    getEvents: (key: string, item?: FilterOption | null) => FilterItemEvent | null;
    onRemoveUpcoming: () => void;
    hasActiveFilter: () => boolean;
}
export declare const useFilter: () => FilterContextModel;
export declare const FilterContext: FC<PropsWithChildren<FilterProps>>;
export {};
