import { ReactNode } from 'react';
import { FlyoutEvents, FlyoutProperties, OptionModel, OptionSingleValue, OptionMultipleValue, FlyoutMode, OptionValue } from '../flyout/type';
import { SearchInputProps } from '../input';
import { DropdownProps } from '../dropdown';
import { EventProps } from '../../hooks/event.hook';
export interface FilterDataValue {
    comparison?: OptionSingleValue;
    values?: OptionMultipleValue;
    [additionalKey: string]: any;
}
export interface FilterData {
    [key: string]: FilterDataValue[];
}
export interface ComparisonOptionModel extends OptionModel {
    multiLabel?: ReactNode;
}
export type FlyoutModeFunction = (val?: FilterDataValue | null) => FlyoutMode;
export interface FilterOption extends FilterItemEvent, Omit<FlyoutProperties, 'items' | 'value' | 'footer' | 'mode'>, Omit<OptionModel, 'value'> {
    mode?: FlyoutMode | FlyoutModeFunction;
    defaultValue?: OptionSingleValue;
    comparisons?: ComparisonOptionModel[];
    footer?: (index: number, key: string, value?: FilterDataValue) => React.ReactNode;
    multiLabel?: (itemValue: OptionMultipleValue) => ReactNode;
    customOption?: (itemValue: OptionSingleValue) => OptionModel;
    customComparisons?: (itemValue: FilterDataValue, index: number) => OptionModel[];
    dynamicItems?: (itemValue: FilterDataValue, index: number) => OptionModel[] | null;
    customValueBox?: (index: number, key: string, value: OptionMultipleValue) => React.ReactNode;
    /** @default "values" */
    valuePropName?: string;
    /** @default "comparison" */
    comparisonPropName?: string;
    /**
     * For multi step filters
     * Starts from SECOND step
     * */
    nextSteps?: FilterOption[];
}
export type FilterItemEvent = Partial<Omit<FlyoutEvents, 'onChange' | 'onNextPage' | 'onSearch' | 'onExpand'>> & {
    onOpen?: (value: FilterDataValue, parent?: OptionModel) => void;
    onChange?: (value: FilterDataValue, addedItems?: OptionModel, removedItems?: OptionModel, parent?: OptionModel) => void | undefined;
    onUpdateValue?: (item: FilterDataValue) => void | undefined;
    onChangeComparison?: (comparison: OptionSingleValue | undefined, item: FilterDataValue) => void | undefined;
    onSearch?: (query: string, value: FilterDataValue, parent?: OptionModel) => void;
    onNextPage?: (value: FilterDataValue, parent?: OptionModel) => void;
    onExpand?: (value: FilterDataValue, parent?: OptionModel) => void;
};
export interface FilterItemEvents {
    [key: string]: FilterItemEvent;
}
export interface FilterSearchProps extends SearchInputProps {
    propName?: string;
    comparison?: string;
    autoCompleteOptions?: string[];
}
export interface FilterTrackEvent {
    filterData: FilterData;
    [key: string]: any;
}
export interface FilterSortTrackEvent {
    value: OptionValue;
    [key: string]: any;
}
export interface FilterProps extends FilterSortingProps, EventProps {
    data: FilterData;
    loading?: boolean;
    /** @deprecated just use data */
    initialData?: FilterData;
    options: FilterOption[];
    /** @deprecated send events in option */
    events?: FilterItemEvents;
    totalResult?: string;
    searchInput?: FilterSearchProps;
    displayDropdown?: DisplayDropdownProps;
    sortByDropdown?: DropdownProps;
    loadProps?: FilterLoadProps;
    mode?: 'default' | 'edit';
    onFilter(data: FilterData, event: 'change' | 'clear'): void;
    onClear?(): void;
}
export interface DisplayDropdownProps extends DropdownProps {
    onReset?: () => void;
    onGearClick?: () => void;
}
export interface FilterSortingProps {
    /**@deprecated use sortByDropdown */
    sortBy?: string;
    /**@deprecated use sortByDropdown */
    sortOptions?: OptionModel[];
    /**@deprecated use sortByDropdown */
    onSort?(key: string, value?: OptionModel): void;
}
export declare enum FilterShareMode {
    private = 0,
    public = 1
}
export interface SaveFilter {
    id?: number;
    name: string;
    description?: string;
    data: FilterData;
    sortBy?: string;
    shareMode: FilterShareMode;
}
export interface FilterSaveProps {
    id?: number;
    data?: SaveFilter;
    options?: OptionModel[];
    loading?: boolean;
    onSelect?(id: number): any | void;
    onSave?(data: SaveFilter): Promise<any | void>;
    onRemove?(id: number): any | void;
    onSearch?(q: string): any | void;
    onNextPage?(): any | void;
}
export interface FilterLoadProps {
    options: OptionModel[];
    selected?: OptionModel;
    value: number;
    loading?: boolean;
    onSelect(id: number): void;
    onSearch(q: string): void;
    onNextPage(): void;
    onClickEdit?: (selected: OptionModel) => void;
    onClickDelete?: (selected: OptionModel) => void;
    confirmModal?: ReactNode;
    showClearButton?: boolean;
}
export interface FilterComponentProps extends FilterProps {
    loadProps?: FilterLoadProps;
    savedSearch?: FilterSaveProps;
    hasAddFilterButton?: boolean;
    action?: ReactNode;
    additionalAction?: ReactNode;
    handleShareMode?: (shareMode: FilterShareMode) => void;
    onAddToList?: () => void;
}
