import { ReactNode } from 'react';
export type FlyoutMode = 'dropdown' | 'single' | 'multi' | 'chip' | 'dnd' | 'cascade';
export type OptionSingleValue = string | number | object;
export type OptionMultipleValue = OptionSingleValue[];
export type OptionValue = OptionSingleValue | OptionMultipleValue;
export interface OptionModel {
    key: string;
    divider?: boolean;
    /** Working in dropdown mode with label */
    isTitle?: boolean;
    value?: OptionValue;
    icon?: ReactNode;
    /** use searchText for search ability if label is React Element */
    label?: ReactNode;
    /** If label is React Element but you want to use search feature, you can use searchText */
    searchText?: string;
    hide?: boolean;
    disabled?: boolean;
    items?: OptionModel[];
    closeable?: boolean;
    editable?: boolean;
}
export interface FlyoutProperties {
    items: OptionModel[];
    value?: OptionValue;
    mode?: FlyoutMode;
    /** This is for Cascade inner items */
    innerMode?: FlyoutMode;
    /** Only one of the cascade options can be selected
     * @default true
     */
    onlyOneCascade?: boolean;
    searchable?: boolean;
    searchLength?: number;
    searchTimeout?: number;
    loading?: boolean;
    header?: React.ReactNode;
    footer?: React.ReactNode;
    secondFooter?: React.ReactNode;
}
export interface FlyoutEvents {
    onChange: (value: OptionValue, addedItems?: OptionModel, removedItems?: OptionModel, parent?: OptionModel) => void | undefined;
    onItemClick?: (item: OptionModel) => void;
    onSearch?: (query: string, parent?: OptionModel) => void;
    onExpand?: (parent?: OptionModel) => void;
    onNextPage?: (parent?: OptionModel) => void;
}
export interface FlyoutProps extends FlyoutProperties, FlyoutEvents {
    initialSearchText?: string;
    height?: number | string;
    borderless?: boolean;
    hasAction?: boolean;
    /** Only works with multi mode */
    renderSelectedItem?: (value: OptionSingleValue) => [() => ReactNode, OptionModel];
}
